@@ -3,11 +3,13 @@ from .exceptions import ValidationError  # noqa
 from .models import (  # noqa
     Address,
     BankAccount,
-    BillingConfiguration,
     BillingInstructions,
     Buyer,
     Card,
+    Discount,
+    Fine,
     InstallmentPlan,
+    Interest,
     Invoice,
     Person,
     Seller,
